@@ -308,7 +308,7 @@ static int parse_request(ci_request_t * req, char *buf)
              if (!(service = find_service(req->service))) { /*else search for an alias */
                  if ((salias = find_service_alias(req->service))) {
                      service = salias->service;
-                     if (salias->args)
+                     if (salias->args[0] != '\0')
                          strcpy(req->args, salias->args);
                  }
              }
@@ -833,6 +833,7 @@ static int get_send_body(ci_request_t * req, int parse_only)
      int (*service_io) (char *rbuf, int *rlen, char *wbuf, int *wlen, int iseof,
                         ci_request_t *);
      int action = 0, rchunkisfull = 0, service_eof = 0, wbytes, rbytes;
+     int lock_status;
      int no_io;
 
      if (parse_only)
@@ -881,6 +882,10 @@ static int get_send_body(ci_request_t * req, int parse_only)
                // if(update_send_status==CI_EOF)/*earlier responce from icap server???...*/
           }
 
+          /*Store lock status. If it is changed during module io, we need
+            to update send status.*/
+          lock_status = req->data_locked;
+
           /*In the following loop, parses the chunks from readed data
              and try to write data to the service.
              At the same time reads the data from module and try to fill
@@ -967,7 +972,7 @@ static int get_send_body(ci_request_t * req, int parse_only)
                action = action | wait_for_write;
           }
 	  
-     } while ((!req->eof_received || (req->eof_received && req->write_to_module_pending)) && action);
+     } while ((!req->eof_received || (req->eof_received && req->write_to_module_pending)) && (action || lock_status != req->data_locked));
 
      if (req->eof_received)
           return CI_OK;
